@@ -8,7 +8,7 @@ print.ssanova <- function(x,...)
     print.default(x$terms$labels)
     cat("\n")
     ## terms overview
-    cat("Number of fixed and random effects:\n\n")
+    cat("Number of unpenalized and penalized terms:\n\n")
     print.default(x$desc)
     cat("\n")
     if (x$method=="v") Method <- "GCV.\n"
@@ -83,7 +83,7 @@ print.ssden <- function(x,...)
     print.default(x$terms$labels)
     cat("\n")
     ## terms overview
-    cat("Number of fixed and random effects:\n\n")
+    cat("Number of unpenalized and penalized terms:\n\n")
     print.default(x$desc)
     cat("\n")
     cat("Smoothing parameters are selected by CV with alpha=",x$alpha,".",sep="")
@@ -102,7 +102,7 @@ print.sshzd <- function(x,...)
     print.default(x$terms$labels)
     cat("\n")
     ## terms overview
-    cat("Number of fixed and random effects:\n\n")
+    cat("Number of unpenalized and penalized terms:\n\n")
     print.default(x$desc)
     cat("\n")
     cat("Smoothing parameters are selected by CV with alpha=",x$alpha,".",sep="")
@@ -121,7 +121,7 @@ print.ssanova1 <- function(x,...)
     print.default(x$terms$labels)
     cat("\n")
     ## terms overview
-    cat("Number of fixed and random effects:\n\n")
+    cat("Number of unpenalized and penalized terms:\n\n")
     print.default(x$desc)
     cat("\n")
     if (x$method=="v") Method <- "GCV "
@@ -144,7 +144,7 @@ print.gssanova1 <- function(x,...)
     print.default(x$terms$labels)
     cat("\n")
     ## terms overview
-    cat("Number of fixed and random effects:\n\n")
+    cat("Number of unpenalized and penalized terms:\n\n")
     print.default(x$desc)
     cat("\n")
     cat("Smoothing parameters are selected by CV with alpha=",x$alpha,".",sep="")
